/*This do-file reproduces the information for Table 1 and Figure 6 of Butler and Butler "Splitting the Difference?"*/

#delimit;

/*Get the data*/
/*NOTE - YOU WILL NEED TO PUT THE FULL PATH NAME OF THE FILE HERE*/
	use "Senate Elections, 46-04.dta", clear;


/*This generates the variables of interest*/
	sort state year eltype;
	gen t= _n;
	tsset state t;
	gen dvs=demvote/(demvote+repvote);
	gen ldvs=l.dvs if l.seat!=seat;
	replace ldvs=l2.dvs if l2.seat!=seat & ldvs==.;
	replace ldvs=l3.dvs if l3.seat!=seat & ldvs==.;
	replace ldvs=l4.dvs if l4.seat!=seat & ldvs==.;
	replace ldvs=l5.dvs if l5.seat!=seat & ldvs==.;
	replace ldvs=l6.dvs if l6.seat!=seat & ldvs==.;
	replace ldvs=. if state==82 & year==1959 |  state==81 & year==1958;
/*Drop observations that aren't being used in the analysis*/
	drop if year<1945;	
	drop if f.year==year;



/*Generate an observation at the break point to get predicted values*/	
	set obs 3002;
	replace ldvs=.5 if _n==3002;


/*Create these variables so that they can be used in running a 4th order polynomial to get the predicted values*/
	orthpoly ldvs if ldvs<=.5, deg(4) generate(pdvs pdvs2 pdvs3 pdvs4);
	regress dvs pdvs pdvs2 pdvs3 pdvs4 if ldvs<.5; 
	predict yhat1 if ldvs<=.5;
	predict stderror1, stdp;
	drop pdvs pdvs2 pdvs3 pdvs4;

	orthpoly ldvs if ldvs>=.5, deg(4) generate(pdvs pdvs2 pdvs3 pdvs4);
	regress dvs pdvs pdvs2 pdvs3 pdvs4 if ldvs>.5 ; 
	predict yhat2 if ldvs>=.5;
	predict stderror2, stdp;
	drop pdvs pdvs2 pdvs3 pdvs4;

/*Display the results for the difference at the cut point based on the polynomial analysis*/
	disp yhat2[_N]-yhat1[_N];
	disp sqrt(stderror1[_N]^2 + stderror2[_N]^2);

/*Results for the Non-parametric analysis*/
	gen D = 0;
	replace D=1 if ldvs>.5;
	replace D=. if ldvs==.;
/*The difference in means based on the whole sample*/
	regress dvs D;
/*10 % Dem-Rep*/
	regress dvs D if ldvs>.4 & ldvs<.6;
/*5 % Dem-Rep*/
	regress dvs D if ldvs>.45 & ldvs<.55;
/*2 % Dem-Rep*/	
	regress dvs D if ldvs>.48 & ldvs<.52;

/*Use the predicted values and the standard errors to generate confidence intervals*/
	g int1U = yhat1 + 2*stderror1;
	g int1L = yhat1 - 2*stderror1;
	g int2U = yhat2 + 2*stderror2;
	g int2L = yhat2 - 2*stderror2;

/*Generate bins to make the picture prettier*/
	gen bin=int(100*ldvs);
	sort bin;
	by bin: egen binave=mean(dvs);
	gen binx= bin/100 +.005;
	sort ldvs;

/*Here is the Graph*/
twoway (scatter binave binx, mcolor(black)) (line yhat1 ldvs, clcolor(black)) 
(line int1U ldvs, clcolor(black) clpat(dash)) (line int1L ldvs, clcolor(black) clpat(dash)) 
(line yhat2 ldvs, clcolor(black)) (line int2U ldvs, clcolor(black) clpat(dash)) 
(line int2L ldvs, clcolor(black) clpat(dash)), 
ytitle(Democratic Vote Share at time t) xtitle(Democratic Vote Share at time t-1 (i.e. for the Sitting Senator)) 
plotregion(style(none)) plotregion(fcolor(white)) graphregion(fcolor(white))
title("Figure 6: Independence of Senate Elections, 1946-2004") xline(.5, lcolor(black) lwidth(vthin)) xlabel(0(.5)1) legend(off);



