/*This do-file runs the test necessary to re-create table A1 in the appendix of Butler & Butler "Splitting the Difference"*/


#delimit;

/*FIRST ROW OF TABLE A1*/
/*First Look at the party incumenbency effect in races with INCUMBENTS*/
/*NOTE - YOU WILL NEED TO PUT THE FULL PATH NAME OF THE FILE HERE*/
	use "Senate Elections, 46-04.dta", clear;
	keep if open==0;


/*This generates the variables of interest*/
	sort state year eltype;
	gen t= _n;
	tsset state t;			
	gen dvs=demvote/(demvote+repvote);
	gen ldvs=l.dvs if l.seat==seat;
	replace ldvs=l2.dvs if l2.seat==seat & ldvs==.;
	replace ldvs=l3.dvs if l3.seat==seat & ldvs==.;
	replace ldvs=l4.dvs if l4.seat==seat & ldvs==.;
	replace ldvs=l5.dvs if l5.seat==seat & ldvs==.;
	replace ldvs=l6.dvs if l6.seat==seat & ldvs==.;
	replace ldvs=. if state==82 & year==1959 |  state==81 & year==1958;


/*Generate an observation at the break point to get predicted values*/	
	drop if year<1945;
	set obs 3200;
	replace ldvs=.5 if _n==_N;


/*Create these variables so that they can be used in running a 4th order polynomial to get the predicted values*/
	orthpoly ldvs if ldvs<=.5, deg(4) generate(pdvs pdvs2 pdvs3 pdvs4);
/*Run the regression*/
	regress dvs pdvs pdvs2 pdvs3 pdvs4 if ldvs<.5; 
/*Get the predicted values*/
	predict yhat1 if ldvs<=.5;
	predict stderror1, stdp;
	drop pdvs pdvs2 pdvs3 pdvs4;

/*Now do the same for observations greater than the cut point*/
	orthpoly ldvs if ldvs>=.5, deg(4) generate(pdvs pdvs2 pdvs3 pdvs4);
	regress dvs pdvs pdvs2 pdvs3 pdvs4 if ldvs>.5 ; 
	predict yhat2 if ldvs>=.5;
	predict stderror2, stdp;

/*Display the results for the difference at the cut point based on the polynomial analysis*/
	disp yhat2[_N]-yhat1[_N];
	disp sqrt(stderror1[_N]^2 + stderror2[_N]^2);

/*Results for the Non-parametric analysis*/
	gen D = 0;
	replace D=1 if ldvs>.5;
	replace D=. if ldvs==.;
/*The difference in means based on the whole sample*/
	regress dvs D;
/*10 % Dem-Rep*/
	regress dvs D if ldvs>.4 & ldvs<.6;
/*5 % Dem-Rep*/
	regress dvs D if ldvs>.45 & ldvs<.55;
/*2 % Dem-Rep*/	
	regress dvs D if ldvs>.48 & ldvs<.52;












/*SECOND ROW OF TABLE A1*/
/*Now Look at the party incumenbency effect in OPEN seats */
/*NOTE - YOU WILL NEED TO PUT THE FULL PATH NAME OF THE FILE HERE*/
	use "Senate Elections, 46-04.dta", clear;
	keep if open==1;


/*This generates the variables of interest*/
	sort state year eltype;
	gen t= _n;
	tsset state t;			
	gen dvs=demvote/(demvote+repvote);
	gen ldvs=l.dvs if l.seat==seat;
	replace ldvs=l2.dvs if l2.seat==seat & ldvs==.;
	replace ldvs=l3.dvs if l3.seat==seat & ldvs==.;
	replace ldvs=l4.dvs if l4.seat==seat & ldvs==.;
	replace ldvs=l5.dvs if l5.seat==seat & ldvs==.;
	replace ldvs=l6.dvs if l6.seat==seat & ldvs==.;
	replace ldvs=. if state==82 & year==1959 |  state==81 & year==1958;


/*Generate an observation at the break point to get predicted values*/	
	drop if year<1945;
	set obs 3200;
	replace ldvs=.5 if _n==_N;


/*Create these variables so that they can be used in running a 4th order polynomial to get the predicted values*/
	orthpoly ldvs if ldvs<=.5, deg(4) generate(pdvs pdvs2 pdvs3 pdvs4);
/*Run the regression*/
	regress dvs pdvs pdvs2 pdvs3 pdvs4 if ldvs<.5; 
/*Get the predicted values*/
	predict yhat1 if ldvs<=.5;
	predict stderror1, stdp;
	drop pdvs pdvs2 pdvs3 pdvs4;

/*Now do the same for observations greater than the cut point*/
	orthpoly ldvs if ldvs>=.5, deg(4) generate(pdvs pdvs2 pdvs3 pdvs4);
	regress dvs pdvs pdvs2 pdvs3 pdvs4 if ldvs>.5 ; 
	predict yhat2 if ldvs>=.5;
	predict stderror2, stdp;

/*Display the results for the difference at the cut point based on the polynomial analysis*/
	disp yhat2[_N]-yhat1[_N];
	disp sqrt(stderror1[_N]^2 + stderror2[_N]^2);

/*Results for the Non-parametric analysis*/
	gen D = 0;
	replace D=1 if ldvs>.5;
	replace D=. if ldvs==.;
/*Gives the difference between Democrats and Republicans when using the whole dataset*/
	regress dvs D;
/*10 % Dem-Rep*/
	regress dvs D if ldvs>.4 & ldvs<.6;
/*5 % Dem-Rep*/
	regress dvs D if ldvs>.45 & ldvs<.55;
/*2 % Dem-Rep*/	
	regress dvs D if ldvs>.48 & ldvs<.52;


